<?php
/**
 * Manages plugin assets.
 *
 * @since 2.12.15
 * @package SWPTLSPRO
 */

namespace SWPTLSPRO;

// If direct access than exit the file.
defined( 'ABSPATH' ) || exit;

/**
 * Manages plugin assets.
 *
 * @since 2.12.15
 * @package SWPTLSPRO
 */
class Assets {

	/**
	 * Class constructor.
	 *
	 * @since 2.13.1
	 */
	public function __construct() {
		add_action( 'gswpts_export_dependency_backend', [ $this, 'tableExportDependencies' ] );
		add_action( 'gswpts_export_dependency_frontend', [ $this, 'exportDependencyScripts' ] );
		add_action( 'gswpts_export_dependency_frontend', [ $this, 'addResponsiveCss' ] );
		add_action( 'wp_head', [ $this, 'printCss' ] );
		add_action( 'admin_head', [ $this, 'gleap_widget' ] );
	}

	/**
	 * Load table export dependencies on the backend.
	 *
	 * @since 2.13.1
	 */
	public function tableExportDependencies() {
		wp_enqueue_script(
			'GSWPTS-buttons',
			SWPTLS_PRO_BASE_URL . 'assets/public/common/DataTables/buttons.min.js',
			[ 'jquery' ],
			SWPTLS_PRO_VERSION,
			true
		);

		wp_enqueue_script(
			'GSWPTS-buttons-flash',
			SWPTLS_PRO_BASE_URL . 'assets/public/common/DataTables/button-flesh.min.js',
			[ 'jquery' ],
			SWPTLS_PRO_VERSION,
			true
		);

		wp_enqueue_script(
			'GSWPTS-jszip',
			SWPTLS_PRO_BASE_URL . 'assets/public/common/DataTables/jszip.min.js',
			[ 'jquery' ],
			SWPTLS_PRO_VERSION,
			true
		);

		wp_enqueue_script(
			'GSWPTS-vfs_fonts',
			SWPTLS_PRO_BASE_URL . 'assets/public/common/DataTables/vfs_fonts.js',
			[ 'jquery' ],
			SWPTLS_PRO_VERSION,
			true
		);

		wp_enqueue_script(
			'GSWPTS-buttons-html5',
			SWPTLS_PRO_BASE_URL . 'assets/public/common/DataTables/buttons.html5.min.js',
			[ 'jquery' ],
			SWPTLS_PRO_VERSION,
			true
		);

		wp_enqueue_script(
			'GSWPTS-buttons-print',
			SWPTLS_PRO_BASE_URL . 'assets/public/common/DataTables/buttons.print.min.js',
			[ 'jquery' ],
			SWPTLS_PRO_VERSION,
			true
		);
	}

	/**
	 * Load table export dependencies on the frontend.
	 *
	 * @since 2.13.1
	 */
	public function exportDependencyScripts() {
		wp_enqueue_script(
			'buttons.min.js',
			SWPTLS_PRO_BASE_URL . 'assets/public/common/DataTables/buttons.min.js',
			[ 'jquery' ],
			'1.10.22',
			true
		);

		wp_enqueue_script(
			'jszip.min.js',
			SWPTLS_PRO_BASE_URL . 'assets/public/common/DataTables/jszip.min.js',
			[ 'jquery' ],
			'3.1.3',
			true
		);

		wp_enqueue_script(
			'vfs_fonts.js',
			SWPTLS_PRO_BASE_URL . 'assets/public/common/DataTables/vfs_fonts.js',
			[ 'jquery' ],
			'3.1.3',
			true
		);

		wp_enqueue_script(
			'buttons.html5.min.js',
			SWPTLS_PRO_BASE_URL . 'assets/public/common/DataTables/buttons.html5.min.js',
			[ 'jquery' ],
			'1.3.3',
			true
		);

		wp_enqueue_script(
			'buttons.print.min.js',
			SWPTLS_PRO_BASE_URL . 'assets/public/common/DataTables/buttons.print.min.js',
			[ 'jquery' ],
			'1.3.3',
			true
		);
	}

	/**
	 * Load responsive css.
	 *
	 * @since 2.13.1
	 */
	public function addResponsiveCss() {
		wp_enqueue_style(
			'GSWPTS-table-responsive',
			SWPTLS_PRO_BASE_URL . 'assets/public/styles/frontend.min.css',
			[],
			SWPTLS_PRO_VERSION,
			'all'
		);
	}

	/**
	 * Print custom css on the head.
	 *
	 * @since 2.13.1
	 */
	public function printCss() {
		$css = get_option( 'css_code_value' );

		if ( $css ) {
			printf( '<style>%s</style>', esc_html( $css ) );
		}
	}

	/**
	 * Add Gleap widget to FlexTable admin pages
	 *
	 * @since 3.18.0
	 */
	public function gleap_widget() {
		if ( ! $this->is_flextable_admin_page() ) {
			return;
		}

		$handle = 'swptls-gleap-init';

		wp_register_script( $handle, '', [], SWPTLS_PRO_VERSION, false );
		wp_enqueue_script( $handle );

		// Prepare user data.
		$current_user = wp_get_current_user();

		// Create the Gleap initialization script.
		$gleap_script = '
			!function(Gleap,t,i){if(!(Gleap=window.Gleap=window.Gleap||[]).invoked){for(window.GleapActions=[],Gleap.invoked=!0,Gleap.methods=["identify","setEnvironment","setTicketAttribute","setTags","attachCustomData","setCustomData","removeCustomData","clearCustomData","registerCustomAction","trackEvent","setUseCookies","log","preFillForm","showSurvey","sendSilentCrashReport","startFeedbackFlow","startBot","setAppBuildNumber","setAppVersionCode","setApiUrl","setFrameUrl","isOpened","open","close","on","setLanguage","setOfflineMode","startClassicForm","initialize","disableConsoleLogOverwrite","logEvent","hide","enableShortcuts","showFeedbackButton","destroy","getIdentity","isUserIdentified","clearIdentity","openConversations","openConversation","openHelpCenterCollection","openHelpCenterArticle","openHelpCenter","searchHelpCenter","openNewsArticle","openChecklists","startChecklist","openNews","openFeatureRequests","isLiveMode"],Gleap.f=function(e){return function(){var t=Array.prototype.slice.call(arguments);window.GleapActions.push({e:e,a:t})}},t=0;t<Gleap.methods.length;t++)Gleap[i=Gleap.methods[t]]=Gleap.f(i);Gleap.load=function(){var t=document.getElementsByTagName("head")[0],i=document.createElement("script");i.type="text/javascript",i.async=!0,i.src="https://sdk.gleap.io/latest/index.js",t.appendChild(i)},Gleap.load(), Gleap.initialize("d8ZYD7leSWHDkJD0vMrmy1ARdEvfPYsu") }}();
			
			// Configure Gleap after initialization
			if (typeof Gleap !== "undefined") {
				// Identify the user for better support
				Gleap.identify("' . esc_js( $current_user->ID ) . '", {
					name: "' . esc_js( $current_user->display_name ) . '",
					email: "' . esc_js( $current_user->user_email ) . '",
					plugin_name: "FlexTable",
					plugin_version: "' . esc_js( SWPTLS_VERSION ) . '",
					wordpress_version: "' . esc_js( get_bloginfo('version') ) . '",
					site_url: "' . esc_js( get_site_url() ) . '",
					pro_active: "' . esc_js( swptls()->helpers->is_pro_active() ? 'yes' : 'no' ) . '",
				});

				// Set custom data for better context
				Gleap.setCustomData({
					environment: "' . esc_js( wp_get_environment_type() ) . '",
					php_version: "' . esc_js( PHP_VERSION ) . '",
					theme: "' . esc_js( get_template() ) . '",
					multisite: "' . esc_js( is_multisite() ? 'yes' : 'no' ) . '"
				});
				
				// console.log("FlexTable: Gleap widget initialized successfully");
			}
		';

		wp_add_inline_script( $handle, $gleap_script );
	}

	/**
	 * Check if current page is FlexTable admin page
	 *
	 * @return bool
	 * @since 3.18.0
	 */
	private function is_flextable_admin_page() {
		$screen = get_current_screen();
		
		// Check if we're on FlexTable dashboard page.
		if ( $screen && 'toplevel_page_gswpts-dashboard' === $screen->id ) {
			return true;
		}
		
		// Check by page parameter for FlexTable pages.
		if ( isset( $_GET['page'] ) ) {
			$flextable_pages = [
				'gswpts-dashboard',
			];
			
			if ( in_array( $_GET['page'], $flextable_pages ) ) {
				return true;
			}
		}
		
		return false;
	}

}